Welcome to ataraxis-video-system API documentation page
=======================================================

ataraxis-video-system is a Python library that interfaces with a wide range of cameras to flexibly record visual stream
data as video files.

This library is part of the broader 'Ataraxis' science-automation project, developed in the
`Sun (NeuroAI) lab <https://neuroai.github.io/sunlab/>`_ at Cornell University.

This website only contains the API documentation for the classes and methods offered by this library. See the project
GitHub repository for installation instructions and library usage examples:
`ataraxis-video-system GitHub repository <https://github.com/Sun-Lab-NBB/ataraxis-video-system>`_.

.. _`ataraxis-video-system GitHub repository`: https://github.com/Sun-Lab-NBB/ataraxis-video-system
.. _`Sun (NeuroAI) lab`: https://neuroai.github.io/sunlab/
